@@ -451,9 +451,11 @@ class fastq2counts(object):
                 # resubmit failed jobs in existing mut_count dir
                 # self.output is the mut_count dir in this case
                 # find out which jobs failed by going through all counts files
-                #self._log.info("Removing existing phred files if they are empty...")
-                #phred_flist = glob.glob(os.path.join(self._output, '*_phred.*'))
-                #if phred_flist != []:
+                self._log.info("Removing existing phred files if they are empty...")
+                phred_flist = glob.glob(os.path.join(self._output, '*_phred.*'))
+                for ph in phred_flist:
+                    if os.stat(file_path).st_size == 0:
+                        os.system(f"rm {os.path.join(self._output, ph)}")
                 #    os.system(f"rm {os.path.join(self._output, '*_phred.*')}")
                 mutcount_list = glob.glob(os.path.join(self._output, "counts_sample_*.csv"))
                 failed_samples = []
